@@ -1,12 +1,9 @@
 from ooPoint import ooPoint
-from numpy import all, atleast_1d, logical_or, logical_and, bool_, vstack
+from numpy import all, atleast_1d, logical_or, logical_and, where, bool_, vstack
 import numpy as np
 from Interval import adjust_lx_WithDiscreteDomain, adjust_ux_WithDiscreteDomain
 from FDmisc import Copy
 
-# for PyPy
-from FDmisc import where
-
 try:
     from bottleneck import nanmin, nanmax
 except ImportError:
@@ -143,7 +140,7 @@ def _iqg(Self, domain, dtype, r0):
     middle = 0.5 * (lb+ub)
     
     if v.domain is not None:
-        middle1, middle2 = middle.copy(), middle#.copy()
+        middle1, middle2 = middle.copy(), middle.copy()
         adjust_ux_WithDiscreteDomain(middle1, v)
         adjust_lx_WithDiscreteDomain(middle2, v)
     else:
